@@ -17,11 +17,16 @@ def test(input_path, tokenizer_path, model_path):
 
             parts = line.strip().split('\t')
 
-            if len(parts) == 6:
+            if len(parts) == 3 or len(parts) == 6:
                 examples.append((parts[0], parts[1]))
                 gold_preds.append(int(parts[2]))
-                names.append(parts[3])
-                quotes.append(f'{parts[4]} - {parts[5]}')
+
+                if len(parts) == 6:
+                    names.append(parts[3])
+                    quotes.append(f'{parts[4]} - {parts[5]}')
+                else:
+                    names.append('NN')
+                    quotes.append('NN')
 
     link_bert_vectorizer = LinkingVectorizer.from_saved(512, tokenizer_path, True)
     link_bert_model = transformers.TFBertForSequenceClassification.from_pretrained(model_path, num_labels=2)
